@@ -1,4 +1,4 @@
-# Copyright (C) 2003-2013 by the gtk2-perl team (see the file AUTHORS for
+# Copyright (C) 2003-2010 by the gtk2-perl team (see the file AUTHORS for
 # the full list)
 #
 # This library is free software; you can redistribute it and/or modify it under
@@ -13,7 +13,7 @@
 #
 # You should have received a copy of the GNU Library General Public License
 # along with this library; if not, write to the Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
 #
 # $Id$
 #
@@ -27,19 +27,18 @@ use Exporter;
 require DynaLoader;
 our @ISA = qw(DynaLoader Exporter);
 
-our $VERSION = '1.291_002';
-
 use constant {
 	TRUE  => 1,
 	FALSE => !1, # can't use !TRUE at this point
-	SOURCE_CONTINUE => 1,
-	SOURCE_REMOVE   => !1,
 	G_PRIORITY_HIGH         => -100,
 	G_PRIORITY_DEFAULT      =>  0,
 	G_PRIORITY_HIGH_IDLE    =>  100,
 	G_PRIORITY_DEFAULT_IDLE =>  200,
 	G_PRIORITY_LOW	        =>  300,
 	G_PARAM_READWRITE       => [qw/readable writable/],
+
+	SOURCE_CONTINUE         => 1,
+	SOURCE_REMOVE           => !1,
 };
 
 # export nothing by default.
@@ -48,8 +47,6 @@ our %EXPORT_TAGS = (
 	constants => [qw/
 			TRUE
 			FALSE
-			SOURCE_CONTINUE
-			SOURCE_REMOVE
 			G_PRIORITY_HIGH
 			G_PRIORITY_DEFAULT
 			G_PRIORITY_HIGH_IDLE
@@ -69,6 +66,8 @@ our %EXPORT_TAGS = (
 our @EXPORT_OK = map { @$_ } values %EXPORT_TAGS;
 $EXPORT_TAGS{all} = \@EXPORT_OK;
 
+our $VERSION = '1.240';
+
 sub dl_load_flags { $^O eq 'darwin' ? 0x00 : 0x01 }
 
 Glib->bootstrap ($VERSION);
@@ -594,8 +593,6 @@ you can also get all of them with the export tag "all".
 
   TRUE
   FALSE
-  SOURCE_CONTINUE
-  SOURCE_REMOVE
   G_PRIORITY_HIGH
   G_PRIORITY_DEFAULT
   G_PRIORITY_HIGH_IDLE
