@@ -9,7 +9,7 @@
 
 package Glib::GenPod;
 
-our $VERSION = '1.291_002';
+our $VERSION = '0.03';
 
 use strict;
 use warnings;
@@ -411,6 +411,7 @@ our %basic_types = (
 	bool     => 'boolean', # C++ keyword, but provided by the perl api
 	boolean  => 'boolean',
 	int      => 'integer',
+	char     => 'integer',
 	uint     => 'unsigned',
 	float    => 'double',
 	double   => 'double',
@@ -601,7 +602,7 @@ sub _pspec_formatted_default {
     # eg. Gtk2::Paned property "max-position" is INT_MAX
     $default = "INT_MAX";
   } elsif ($type eq 'Glib::Int' && $default == POSIX::INT_MIN()) {
-    $default = "INT_MIN";
+    $default = "INT_MAX";
   } elsif ($type eq 'Glib::UInt' && $default == POSIX::UINT_MAX()) {
     $default = "UINT_MAX";
 
@@ -1216,7 +1217,7 @@ sub convert_type {
 	              \s*$/x;				# trailing space
 	my $ctype   = $1 || '!!';
 	if ($ctype eq '!!') {
-		warn "Glib::GenPod: Unable to parse type '$typestr'";
+		warn "Glib::GenPod: Unable to parse type `$typestr´";
 	}
 
 	# variant type
@@ -1539,10 +1540,10 @@ mcfarland hacked this module together via irc and email over the next few days.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2003-2004, 2010-2012 by the gtk2-perl team
+Copyright (C) 2003-2004, 2010, 2011 by the gtk2-perl team
 
 This library is free software; you can redistribute it and/or modify
-it under the terms of the Lesser General Public License (LGPL).  For
+it under the terms of the Lesser General Public License (LGPL).  For 
 more information, see http://www.fsf.org/licenses/lgpl.txt
 
 =cut
