@@ -1,26 +1,26 @@
 # Copyright (C) 2003-2004, 2010 by the gtk2-perl team (see the file AUTHORS for
 # the full list)
-#
+# 
 # This library is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Library General Public License as published by the Free
 # Software Foundation; either version 2.1 of the License, or (at your option)
 # any later version.
-#
+# 
 # This library is distributed in the hope that it will be useful, but WITHOUT
 # ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 # FOR A PARTICULAR PURPOSE.  See the GNU Library General Public License for
 # more details.
-#
+# 
 # You should have received a copy of the GNU Library General Public License
 # along with this library; if not, write to the Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
 #
 # $Id$
 #
 
 package Glib::Object::Subclass;
 
-our $VERSION = '1.291_002';
+our $VERSION = '0.03';
 
 use Glib;
 
@@ -223,18 +223,16 @@ do that.  Especially watch out for other classes in your ISA tree.
 *new = \&Glib::Object::new;
 
 sub import {
-   shift;  # $self
-
    # we seem to be imported by classes using classes which use us.
    # ignore anything that doesn't look like a registration attempt.
-   return unless @_;
+   return unless @_ > 1;
 
-   my $superclass = shift;
+   my ($self, $superclass, %arg) = @_;
    my $class = caller;
 
    Glib::Type->register_object(
       $superclass, $class,
-      @_,
+      %arg,
    );
 
    # ensure that we have a perlish new().  the old version of this
